@@ -93,6 +93,12 @@ void testDriveBt_clicked_cb(HildonButton * button, QueenBeecon *self)
 	gchar *buff = g_strdup_printf("[Exit Code = %d Output Size = %d]\n%s", (char)exitCode, l, line);//If command has output we issue a newline after Exit Code
 	qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) to out buffer(l=%d,buff=%s)", self, strlen(buff), buff);
 	gtk_text_buffer_set_text(self->priv->cmdOutputBuffer,buff,strlen(buff));
+
+	gtk_text_buffer_get_bounds (self->priv->cmdOutputBuffer, &start, &end);
+	if (g_strcmp0(gtk_text_buffer_get_text (self->priv->cmdOutputBuffer,&start, &end, FALSE), buff)) {
+		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) QBW Warning! Expected/Shown Command Output mismatch. Possible charset different from UTF-8!", self);
+		hildon_banner_show_informationf (NULL, NULL, "(%p) QBW Warning! Expected/Shown Command Output mismatch. Possible charset different from UTF-8!", self);
+	}
 	g_free(buff);
 	g_free(line);
 	g_free(c);
