@@ -182,22 +182,26 @@ struct _QueenBeeconPrivate
 		guint			progressAnimationFrames;
 		guint			progressAnimationTimer;
 		guint			progressAnimationPos;
+		gboolean		progressAnimationAtClickXY;
 		gchar			*progressAnimationBasename;
 
 		gboolean 		hideCanvas;
+		gboolean 		hideClickCanvas;
 		gboolean 		updOnStartup;
 		gboolean 		updOnClick;
 		gboolean 		isPressed;
 		gboolean 		clicksCount;
 		guint 			clicksTimerID;
-		gint			clickX;
-		gint			clickY;
-		GtkWidget 		*clickWidget;
+		gint			clickX,xx;
+		gint			clickY,yy;
+		//gboolean		isFingerTap;
 
 		gboolean 		updOnDesktop;
 		guint 			updNeworkPolicy;
 		gboolean 		updOnSight;
 		gboolean 		qbwOnSight;
+		gboolean		startupAnimation;
+		gboolean		animationInProgress;
 
 		gint			widXOrigin;
 		gint			widYOrigin;
@@ -238,22 +242,14 @@ struct _QueenBeeconPrivate
 		gchar			*rememberMe;
 
 		GtkWidget 		*tableLayout;
-#ifndef MONO_HOTSPOT
 		GtkWidget 		*hotSpot;
 		GtkWidget 		*hotSpotEvent;
-#else // MONO_HOTSPOT
-#ifndef OLD_HOTSPOT_INDEX
-		GtkWidget 		*hotSpots[9][3][3];
-		GtkWidget 		*hotSpotsEvents[9][3][3];
-		guint			subHotSpotIndex;
-#else // OLD_HOTSPOT_INDEX
-		GtkWidget 		*hotSpots[3][3];
-		GtkWidget 		*hotSpotsEvents[3][3];
-#endif // OLD_HOTSPOT_INDEX
-#endif // MONO_HOTSPOT
 		guint			hotSpotIndex;
 		GtkWidget 		*tableHotSpots;
+
+		GtkWidget 		*beeExecuting_fixed;
 		GtkWidget 		*beeExecuting_img;
+		GtkWidget 		*beeExecuting_lb;
 		GdkPixbuf      	*beeExecuting_pixbuf[QBW_PROGRESS_ANIMATION_FRAMES_MAX];
 		guint			beeExecuting_imgidx;
 		gchar			*cmdImgFilename;
@@ -306,6 +302,7 @@ struct _QueenBeeconPrivate
 		//exec input/output
 		gchar			*execAuxOutput;
 		gboolean		execInProgress;
+		gboolean		clickExecInProgress;
 		GMutex 			*execInProgressMutex;
 		guint			child_watch_id;
 		guint			io_watch_id;
@@ -315,6 +312,7 @@ struct _QueenBeeconPrivate
 		guint 			delayIndex;//index of delaySeconds in the array defined inside "queen_beecon_settings"
 		guint 			customIntervalSecs;//custom interval in seconds
 
+		guint 			startupExecTimerID;
 		//timer process id; used to stop when closing app or changing delay
 		guint 			updateTimerID;
 
@@ -376,6 +374,7 @@ struct _QueenBeeconPrivate
 		GtkWidget *widgetBgLabelW;
 		GtkWidget *hidCanvSnipBgBoxW;
 		GtkWidget *checkBtHideCanvasW;
+		GtkWidget *checkBtHideClkCanvasW;
 		GdkColor snippetBgRGBC;
 		GtkWidget *snippetBgRGBSelectorW;
 		GtkWidget *snippetBgRGBW;
@@ -486,6 +485,7 @@ struct _QueenBeeconPrivate
 		GtkWidget *progrAnimTimerW;
 		GtkWidget *progrAnimPosSelectorW;
 		GtkWidget *progrAnimPosW;
+		GtkWidget *checkAnimClkXYW;
 		GtkWidget *progrAnimBaseLabelW;
 		GtkWidget *progrAnimBasenameW;
 
